/********************************************************************************
** Form generated from reading UI file 'fontsdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTSDLG_H
#define UI_FONTSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <kfontchooser.h>
#include <klocalizedstring.h>
#include "kfontchooser.h"

QT_BEGIN_NAMESPACE

class Ui_fontsdlg
{
public:

    void setupUi(KFontChooser *kcfg_Font)
    {
        if (kcfg_Font->objectName().isEmpty())
            kcfg_Font->setObjectName("kcfg_Font");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(48);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        kcfg_Font->setFont(font);

        retranslateUi(kcfg_Font);

        QMetaObject::connectSlotsByName(kcfg_Font);
    } // setupUi

    void retranslateUi(KFontChooser *kcfg_Font)
    {
        (void)kcfg_Font;
    } // retranslateUi

};

namespace Ui {
    class fontsdlg: public Ui_fontsdlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FONTSDLG_H

